| ArmFinishedCondition-class | R Documentation |
ArmFinishedConditionArmFinishedCondition opens an arm when the named arm has finished dose
escalation.
ArmFinishedCondition(arm_name)
.DefaultArmFinishedCondition()
arm_name |
( |
arm_name(string)
the name of the arm that must have finished.
Typically, end users will not use the
.DefaultArmFinishedCondition() function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.