HierarchicalData-class: 'HierarchicalData'

HierarchicalData-classR Documentation

HierarchicalData

Description

[Experimental]

HierarchicalData is a class for hierarchical designs, storing the data for all arms together.

Usage

HierarchicalData(...)

.DefaultHierarchicalData()

Arguments

...

named Data objects, one for each arm in the trial. The argument names are used as the arm names.

Slots

arms

(list)
a named list of Data objects, one for each arm in the trial. The names of the list are the arm names.

Note

Typically, end users will not use the .DefaultHierarchicalData() function directly.

Examples

dat_hierarchical <- HierarchicalData(
  mono = .DefaultData(),
  combo = .DefaultDataCombo()
)

crmPack documentation built on July 5, 2026, 9:06 a.m.