| OpeningList-class | R Documentation |
OpeningListOpeningList is a virtual class for combining multiple Opening objects
using logical operators. It is used as a base class for OpeningAll and
OpeningAny.
OpeningList(...)
.DefaultOpeningList()
... |
( |
open_list(list)
a list of Opening objects to be combined.
Typically, end users will not use the .DefaultOpeningList() function.
Opening, OpeningAll, OpeningAny.
# Create two simple opening criteria
opening1 <- OpeningMinDose(min_dose = 10)
opening2 <- OpeningMinCohorts(min_cohorts = 3)
# Create an OpeningList that combines them
opening_list <- OpeningList(opening1, opening2)
print(opening_list)
# You can also create with more than two criteria
opening3 <- OpeningNone()
opening_list_multi <- OpeningList(opening1, opening2, opening3)
print(opening_list_multi)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.