| OpeningMinCohorts-class | R Documentation |
OpeningMinCohortsOpeningMinCohorts opens backfill cohorts when the overall number of
cohorts treated so far in the trial reaches or exceeds a minimum threshold.
This can be used to implement a "delayed backfill cohort opening" rule.
OpeningMinCohorts(min_cohorts = 2L)
.DefaultOpeningMinCohorts()
min_cohorts |
( |
min_cohorts(integer)
the minimum number of cohorts that must
have been treated before backfilling can be opened.
Typically, end users will not use the .DefaultOpeningMinCohorts() function.
Opening and the other subclasses listed in there.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.