OpeningMinDose-class: 'OpeningMinDose'

OpeningMinDose-classR Documentation

OpeningMinDose

Description

[Experimental]

OpeningMinDose opens a backfill cohort when the cohort's dose is above or equal to the minimum dose specified. Note that the next recommended dose is not taken into account.

Usage

OpeningMinDose(min_dose = 0)

.DefaultOpeningMinDose()

Arguments

min_dose

(number)
see slot definition.

Slots

min_dose

(numeric)
the minimum dose at which backfill cohorts can be opened. For combination trials, this can be a vector of minimum doses for each agent.

Note

Typically, end users will not use the .DefaultOpeningMinDose() function.

See Also

Opening and the other subclasses listed in there.

Examples

# Opening backfill cohort when dose is at least 50
my_opening <- OpeningMinDose(min_dose = 50)

crmPack documentation built on July 5, 2026, 9:06 a.m.