| OpeningMinResponses-class | R Documentation |
OpeningMinResponsesOpeningMinResponses opens backfill cohorts when a minimum number of
responses has been observed in the trial. The responses can be counted
at the cohort's dose level only, or also at lower dose levels if
include_lower_doses is set to TRUE.
OpeningMinResponses(min_responses = 1L, include_lower_doses = FALSE)
.DefaultOpeningMinResponses()
min_responses |
( |
include_lower_doses |
( |
min_responses(count)
the minimum number of responses
required before backfill cohorts can be opened (at least 1).
include_lower_doses(logical)
if TRUE, responses at all
doses less than or equal to the cohort's dose are counted. If FALSE,
only responses at the cohort's dose are counted.
Typically, end users will not use the .DefaultOpeningMinResponses() function.
Opening and the other subclasses listed in there.
# Create an OpeningMinResponses object that requires 2 responses
opening <- OpeningMinResponses(min_responses = 2, include_lower_doses = FALSE)
# Display the object
print(opening)
# Create a variant that includes lower doses
opening_inclusive <- OpeningMinResponses(
min_responses = 2,
include_lower_doses = TRUE
)
print(opening_inclusive)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.