| Recruitment-class | R Documentation |
RecruitmentRecruitment is a virtual class for recruitment criteria, from which all
other specific recruitment criteria classes inherit.
The subclasses are used to specify the maximum number of backfill patients
that can be recruited relative to the main trial cohort size.
.DefaultRecruitment()
Typically, end users will not use the .DefaultRecruitment() function.
RecruitmentUnlimited, RecruitmentRatio.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.