| RecruitmentRatio-class | R Documentation |
RecruitmentRatioRecruitmentRatio constrains the recruitment of backfill patients
based on a ratio to the main trial cohort size. The maximum number of
backfill patients is calculated as ceiling(ratio * active_cohort_size).
RecruitmentRatio(ratio = 1)
.DefaultRecruitmentRatio()
ratio |
( |
ratio(number)
the recruitment ratio, specifying the maximum number of backfill patients
per patient in the main trial cohort (non-negative).
Typically, end users will not use the .DefaultRecruitmentRatio() function.
Recruitment and the other subclasses listed in there.
# Create a RecruitmentRatio object with ratio 0.5
# This means 1 backfill patient for every 2 patients in the active cohort
recruitment <- RecruitmentRatio(ratio = 0.5)
print(recruitment)
# Create a variant with ratio 1 (1:1)
recruitment_one_to_one <- RecruitmentRatio(ratio = 1)
print(recruitment_one_to_one)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.