| RecruitmentUnlimited-class | R Documentation |
RecruitmentUnlimitedRecruitmentUnlimited allows unlimited recruitment of backfill patients.
There is no constraint on the number of backfill patients relative to the
main trial cohort size.
RecruitmentUnlimited()
.DefaultRecruitmentUnlimited()
Typically, end users will not use the .DefaultRecruitmentUnlimited() function.
Recruitment and the other subclasses listed in there.
# Create a RecruitmentUnlimited object
recruitment <- RecruitmentUnlimited()
print(recruitment)
# Calculate maximum recruits for an active cohort of size 10
max_recruits <- maxRecruits(recruitment, active_cohort_size = 10)
print(max_recruits) # Practically unlimited (1e6)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.