| StoppingCohortsNearDose-class | R Documentation |
StoppingCohortsNearDoseStoppingCohortsNearDose is the class for stopping based on number of
cohorts near to next best dose.
StoppingCohortsNearDose(
nCohorts = 2L,
percentage = 50,
report_label = NA_character_
)
.DefaultStoppingCohortsNearDose()
nCohorts |
( |
percentage |
( |
report_label |
( |
nCohorts(number)
number of required cohorts.
percentage(number)
percentage (between and including 0 and 100)
within the next best dose the cohorts must lie. This is applied
for each of the two doses for DataCombo objects.
Typically, end users will not use the .DefaultStoppingCohortsNearDose() function.
# Here, is the rule for stopping the study if at least 3 cohorts were dosed
# at a dose within (1 +/- 0.2) of the next best dose.
my_stopping <- StoppingCohortsNearDose(
nCohorts = 3,
percentage = 0.2
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.