TITELogisticLogNormalSub-class: 'TITELogisticLogNormalSub'

TITELogisticLogNormalSub-classR Documentation

TITELogisticLogNormalSub

Description

[Stable]

TITELogisticLogNormalSub is the class for TITE-CRM based on a logistic regression model with subtractive dose standardization and a bivariate normal prior on the intercept and log slope parameters.

This class inherits from LogisticLogNormalSub.

Usage

TITELogisticLogNormalSub(weight_method = "linear", ...)

.DefaultTITELogisticLogNormalSub()

Arguments

weight_method

(string)
see the slot description.

...

Arguments passed on to LogisticLogNormalSub

mean

(numeric)
the prior mean vector.

cov

(matrix)
the prior covariance matrix. The precision matrix prec is internally calculated as an inverse of cov.

ref_dose

(number)
the reference dose x*.

Details

Basically, the adaptive function allocates more weight to each record than the linear function when DLTs are observed early and less weight when DLTs are observed late. When DLT times are evenly distributed both weights are similar. In addition, with more DLTs, the adaptive weights become more extreme and different from the linear weights.

Slots

weight_method

(string)
the weight function method: either linear or adaptive; see \insertCiteLiuYinYuan2013;textualcrmPack.

Note

Typically, end users will not use the .DefaultTITELogisticLogNormalSub() function.

References

\insertAllCited

See Also

TITELogisticLogNormal, DALogisticLogNormal.

Examples

my_model <- TITELogisticLogNormalSub(
  mean = c(-0.85, 1),
  cov = matrix(c(1, -0.5, -0.5, 1), nrow = 2),
  ref_dose = 50,
  weight_method = "linear"
)

my_model1 <- TITELogisticLogNormalSub(
  mean = c(-0.85, 1),
  cov = matrix(c(1, -0.5, -0.5, 1), nrow = 2),
  ref_dose = 50,
  weight_method = "adaptive"
)

crmPack documentation built on July 5, 2026, 9:06 a.m.