Learn R Programming

crmPack (version 0.2.7)

Validate: A Reference Class to help programming validation for new S4 classes

Description

Starting from an empty msg vector, with each check that is returning FALSE the vector gets a new element - the string explaining the failure of the validation

Arguments

Fields

msg

the message character vector