h_enroll_backfill_patients: Helper Function to Enroll Backfill Patients

View source: R/helpers_design.R

h_enroll_backfill_patientsR Documentation

Helper Function to Enroll Backfill Patients

Description

This function executes backfill enrollment according to the priority rule, updating the data object, backfill cohort queue, and patient counter.

Usage

h_enroll_backfill_patients(
  backfill_cohorts,
  data,
  backfill,
  cohort_size,
  backfill_patients,
  current_args,
  truth,
  truthResponse
)

Arguments

backfill_cohorts

(list)
current queue of backfill cohorts.

data

(Data)
current trial data.

backfill

(Backfill)
with priority and recruitment rules.

cohort_size

(count)
size of the active cohort.

backfill_patients

(count)
number of enrolled backfill patients.

current_args

(data.frame)
arguments for the truth function.

truth

(function)
defining true DLT probability.

truthResponse

(function)
defining true response probability.

Value

List with updated data, backfill_cohorts, and backfill_patients.


crmPack documentation built on July 5, 2026, 9:06 a.m.