h_hierarchical_model_type: Identify the Internal Type of a Hierarchical Arm Model

View source: R/HierarchicalModel-class.R

h_hierarchical_model_typeR Documentation

Identify the Internal Type of a Hierarchical Arm Model

Description

[Experimental]

Maps the currently supported hierarchical arm models to compact internal labels used by the code generators.

Usage

h_hierarchical_model_type(model)

Arguments

model

(GeneralModel)
arm-specific model object.

Value

Either "mono" or "combo".


crmPack documentation built on July 5, 2026, 9:06 a.m.