View source: R/HierarchicalModel-class.R
| h_hierarchical_parse_ref | R Documentation |
Converts a user-facing parameter reference into metadata that can be used by the JAGS code generators.
h_hierarchical_parse_ref(model, arm_name, ref)
model |
( |
arm_name |
( |
ref |
( |
Named list with entries kind, index, latent, and sample.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.