View source: R/HierarchicalModel-class.R
| h_hierarchical_safe_name | R Documentation |
Replaces every non-alphanumeric character with an underscore so that user supplied arm and pool names can safely be embedded in generated JAGS variable names.
h_hierarchical_safe_name(name)
name |
( |
A character scalar suitable for generated JAGS identifiers.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.