View source: R/HierarchicalDesign-class.R
| h_historical_arm_design | R Documentation |
Construct a simplified DesignArm with hardcoded rule objects
h_historical_arm_design(data, model)
data |
( |
model |
( |
A Design object with hardcoded rules for historical arms. The rules
don't matter because they won't be used, but they are required to construct a Design object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.