| h_mcmc_get_hierarchical_data | R Documentation |
HierarchicalData into JAGS Input for a HierarchicalModelPrepares the data list consumed by the dynamically compiled hierarchical JAGS model. Arm-specific data are renamed with arm-specific prefixes so they align with the generated model code.
h_mcmc_get_hierarchical_data(model, data, from_prior)
model |
( |
data |
( |
from_prior |
( |
Named list suitable for rjags::jags.model(data = ...).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.