h_update_backfill_queue: Helper Function to Update Backfill Queue

View source: R/helpers_design.R

h_update_backfill_queueR Documentation

Helper Function to Update Backfill Queue

Description

This function manages the backfill cohort queue by determining which previous cohorts are open or closed for backfill enrollment.

Usage

h_update_backfill_queue(backfill_cohorts, data, dose, backfill)

Arguments

backfill_cohorts

(list)
current queue of backfill cohorts.

data

(Data)
current trial data.

dose

(number)
current dose being evaluated.

backfill

(Backfill)
with opening rules and cohort size.

Value

Updated backfill_cohorts list.


crmPack documentation built on July 5, 2026, 9:06 a.m.