Learn R Programming

crmPack (version 2.2.1)

plot,ComboSimulations,missing-method: Plot ComboSimulations

Description

[Experimental]

Summarize two-drug combination simulations with plots.

This plot method can be applied to ComboSimulations objects. Possible types of plots are:

trajectory

Summary of simulated dose trajectories for each drug

dosesTried

Average proportions of tested doses for each drug

trajectory2D

2D dose-plane evolution with arrows for dose transitions, and labels showing DLTs/patients plus a step index hint

Usage

# S4 method for ComboSimulations,missing
plot(x, y, type = c("trajectory", "dosesTried", "trajectory2D"), ...)

Value

A single ggplot object if a single panel is produced, otherwise a gtable object.

Arguments

x

(ComboSimulations)
the object we want to plot from.

y

(missing)
not used.

type

(character)
the type of plots you want to obtain.

...

not used.