| prob | R Documentation |
A function that computes the probability of the occurrence of a DLE at a specified dose level, based on the model parameters (samples).
prob(dose, model, samples, ...)
## S4 method for signature 'numeric,LogisticNormal,Samples'
prob(dose, model, samples, ...)
## S4 method for signature 'numeric,LogisticLogNormal,Samples'
prob(dose, model, samples, ...)
## S4 method for signature 'numeric,LogisticLogNormalSub,Samples'
prob(dose, model, samples, ...)
## S4 method for signature 'numeric,ProbitLogNormal,Samples'
prob(dose, model, samples, ...)
## S4 method for signature 'numeric,ProbitLogNormalRel,Samples'
prob(dose, model, samples, ...)
## S4 method for signature 'numeric,LogisticLogNormalGrouped,Samples'
prob(dose, model, samples, group, ...)
## S4 method for signature 'numeric,TwoDrugsCombo,Samples'
prob(dose, model, samples, ...)
## S4 method for signature 'matrix,TwoDrugsCombo,Samples'
prob(dose, model, samples, ...)
## S4 method for signature 'numeric,LogisticKadane,Samples'
prob(dose, model, samples, ...)
## S4 method for signature 'numeric,LogisticKadaneBetaGamma,Samples'
prob(dose, model, samples, ...)
## S4 method for signature 'numeric,LogisticNormalMixture,Samples'
prob(dose, model, samples, ...)
## S4 method for signature 'numeric,LogisticNormalFixedMixture,Samples'
prob(dose, model, samples, ...)
## S4 method for signature 'numeric,LogisticLogNormalMixture,Samples'
prob(dose, model, samples, ...)
## S4 method for signature 'numeric,DualEndpoint,Samples'
prob(dose, model, samples, ...)
## S4 method for signature 'numeric,LogisticIndepBeta,Samples'
prob(dose, model, samples, ...)
## S4 method for signature 'numeric,LogisticIndepBeta,missing'
prob(dose, model, samples, ...)
## S4 method for signature 'numeric,OneParLogNormalPrior,Samples'
prob(dose, model, samples, ...)
## S4 method for signature 'numeric,OneParExpPrior,Samples'
prob(dose, model, samples, ...)
## S4 method for signature 'numeric,LogisticLogNormalOrdinal,Samples'
prob(dose, model, samples, grade, cumulative = TRUE, ...)
dose |
( |
model |
( |
samples |
( |
... |
model specific parameters when |
group |
( |
grade |
( |
cumulative |
( |
The prob() function computes the probability of toxicity for given
doses, using samples of the model parameter(s).
If you work with multivariate model parameters, then assume that your model
specific prob() method receives a samples matrix where the rows
correspond to the sampling index, i.e. the layout is then
nSamples x dimParameter.
A proportion or numeric vector with the toxicity probabilities,
or a numeric matrix for methods that evaluate multiple dose combinations at
once. If non-scalar samples were used, then every element in the returned
vector corresponds to one element of a sample. Hence, in this case, the
output vector is of the same length as the sample vector. If scalar
samples were used or no samples were used, e.g. for pseudo
DLE/toxicity model, then the output is of the same length as the length
of the dose. For matrix-valued dose inputs, the returned matrix contains
one column per dose combination. In the case of LogisticLogNormalOrdinal,
the probabilities relate to toxicities of grade given by grade.
prob(dose = numeric, model = LogisticNormal, samples = Samples): Calculate toxicity probabilities for a LogisticNormal model.
prob(dose = numeric, model = LogisticLogNormal, samples = Samples): Calculate toxicity probabilities for a LogisticLogNormal model.
prob(dose = numeric, model = LogisticLogNormalSub, samples = Samples): Calculate toxicity probabilities for a LogisticLogNormalSub model.
prob(dose = numeric, model = ProbitLogNormal, samples = Samples): Calculate toxicity probabilities for a ProbitLogNormal model.
prob(dose = numeric, model = ProbitLogNormalRel, samples = Samples): Calculate toxicity probabilities for a ProbitLogNormalRel model.
prob(dose = numeric, model = LogisticLogNormalGrouped, samples = Samples): method for LogisticLogNormalGrouped which needs group
argument in addition.
prob(dose = numeric, model = TwoDrugsCombo, samples = Samples): method for TwoDrugsCombo for a single dose
combination provided as a named numeric vector.
prob(dose = matrix, model = TwoDrugsCombo, samples = Samples): method for TwoDrugsCombo for one or more dose
combinations provided in the rows of a numeric matrix.
prob(dose = numeric, model = LogisticKadane, samples = Samples): Calculate toxicity probabilities for a LogisticKadane model.
prob(dose = numeric, model = LogisticKadaneBetaGamma, samples = Samples): Calculate toxicity probabilities for a LogisticKadaneBetaGamma model.
prob(dose = numeric, model = LogisticNormalMixture, samples = Samples): Calculate toxicity probabilities for a LogisticNormalMixture model.
prob(dose = numeric, model = LogisticNormalFixedMixture, samples = Samples): Calculate toxicity probabilities for a LogisticNormalFixedMixture model.
prob(dose = numeric, model = LogisticLogNormalMixture, samples = Samples): Calculate toxicity probabilities for a LogisticLogNormalMixture model.
prob(dose = numeric, model = DualEndpoint, samples = Samples): Calculate toxicity probabilities for a DualEndpoint model.
prob(dose = numeric, model = LogisticIndepBeta, samples = Samples): compute toxicity probabilities of the occurrence of a DLE at
a specified dose level, based on the samples of LogisticIndepBeta model
parameters.
prob(dose = numeric, model = LogisticIndepBeta, samples = missing): compute toxicity probabilities of the occurrence of a DLE at
a specified dose level, based on the LogisticIndepBeta model parameters.
All model parameters (except dose) should be present in the model object.
prob(dose = numeric, model = OneParLogNormalPrior, samples = Samples): Calculate toxicity probabilities for a OneParLogNormalPrior model.
prob(dose = numeric, model = OneParExpPrior, samples = Samples): Calculate toxicity probabilities for a OneParExpPrior model.
prob(dose = numeric, model = LogisticLogNormalOrdinal, samples = Samples): Calculate grade-specific toxicity probabilities for a LogisticLogNormalOrdinal model.
The prob() and dose() functions are the inverse of
each other, for all dose() methods for which its first argument, i.e. a
given independent variable that dose depends on, represents toxicity
probability.
probFunction(), dose(), efficacy().
# Create some data.
my_data <- Data(
x = c(0.1, 0.5, 1.5, 3, 6, 10, 10, 10),
y = c(0, 0, 0, 0, 0, 0, 1, 0),
cohort = c(0, 1, 2, 3, 4, 5, 5, 5),
doseGrid = c(0.1, 0.5, 1.5, 3, 6, seq(from = 10, to = 80, by = 2))
)
# Initialize a model, e.g. 'LogisticLogNormal'.
my_model <- LogisticLogNormal(
mean = c(-0.85, 1),
cov = matrix(c(1, -0.5, -0.5, 1), nrow = 2),
ref_dose = 56
)
# Get samples from posterior.
my_options <- McmcOptions(burnin = 100, step = 2, samples = 20)
my_samples <- mcmc(data = my_data, model = my_model, options = my_options)
# Posterior for Prob(DLT | dose = 50).
prob(dose = 50, model = my_model, samples = my_samples)
# Create data from the 'DataDual' class.
data_dual <- DataDual(
x = c(25, 50, 25, 50, 75, 300, 250, 150),
y = c(0, 0, 0, 0, 0, 1, 1, 0),
w = c(0.31, 0.42, 0.59, 0.45, 0.6, 0.7, 0.6, 0.52),
doseGrid = seq(from = 25, to = 300, by = 25)
)
# Initialize a toxicity model using 'LogisticIndepBeta' model.
dlt_model <- LogisticIndepBeta(
binDLE = c(1.05, 1.8),
DLEweights = c(3, 3),
DLEdose = c(25, 300),
data = data_dual
)
# Get samples from posterior.
dlt_sample <- mcmc(data = data_dual, model = dlt_model, options = my_options)
# Posterior for Prob(DLT | dose = 100).
prob(dose = 100, model = dlt_model, samples = dlt_sample)
prob(dose = c(50, 150), model = dlt_model)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.