# S4 method for HierarchicalDesign
simulate(
object,
nsim = 1L,
seed = NULL,
truth,
truthResponse = plogis,
args = NULL,
firstSeparate = FALSE,
mcmcOptions = McmcOptions(),
parallel = FALSE,
nCores = min(parallel::detectCores(), 5),
derive = list(),
...
)an object of class HierarchicalSimulations.
the HierarchicalDesign object we want to simulate data from.
(count)
the number of simulations.
see set_seed().
(function or named list of function)
true DLT
probability function(s). If a list is supplied, names must match the
hierarchical arms.
(function or named list of function)
true
response probability function(s).
(data.frame)
arguments for the truth functions.
(flag)
enroll the first patient separately from the rest of
the cohort? (not default) If yes, the cohort will be closed if a DLT occurs
in this patient.
(McmcOptions)
object of class McmcOptions,
giving the MCMC options for each evaluation in the trial. By default,
the standard options are used
(flag)
should the simulation runs be parallelized across the
clusters of the computer? (not default)
(count)
how many cores should be used for parallel computing?
Defaults to the number of cores on the machine, maximum 5.
(list)
a named list of functions which derives statistics, based on the
vector of posterior MTD samples. Each list element must therefore accept
one and only one argument, which is a numeric vector, and return a number.
not used