Learn R Programming

crmPack (version 2.2.1)

update,HierarchicalData-method: Updating HierarchicalData Objects

Description

[Experimental]

A method that updates one arm in a HierarchicalData object with new data.

Usage

# S4 method for HierarchicalData
update(object, arm, ..., check = TRUE)

Value

The new, updated HierarchicalData object.

Arguments

object

(HierarchicalData)
object you want to update.

arm

(string)
name of the arm to update.

...

arguments passed to the selected arm's update method.

check

(flag)
whether the validation of the updated object should be conducted.