v_backfill: Internal Helper Functions for Validation of 'Backfill'...

View source: R/Backfill-validity.R

v_backfillR Documentation

Internal Helper Functions for Validation of Backfill Objects

Description

[Experimental]

These functions are only used internally to validate the format of an input Backfill object and therefore not exported.

Usage

v_backfill(object)

Arguments

object

(Backfill)
object to validate.

Value

A character vector with the validation failure messages, or TRUE in case validation passes.

Functions

  • v_backfill(): validates that the Backfill object contains valid slots.


crmPack documentation built on July 5, 2026, 9:06 a.m.