GeneralData ObjectsThese functions are only used internally to validate the format of an input
GeneralData or inherited classes and therefore not exported.
v_general_data(object)h_doses_unique_per_cohort(dose, cohort)
h_combo_doses_unique_per_cohort(x, cohort)
v_data(object)
v_data_dual(object)
v_data_parts(object)
v_data_mixture(object)
v_data_da(object)
v_data_ordinal(object)
v_data_grouped(object)
v_data_combo(object)
v_hierarchical_data(object)
A character vector with the validation failure messages,
or TRUE in case validation passes.
TRUE if dose is unique per cohort, otherwise FALSE.
TRUE if x is unique per cohort, otherwise FALSE.
(GeneralData)
object to validate.
(numeric)
dose values.
(integer)
(matrix)
v_general_data(): validates that the GeneralData
object contains unique ID, non-negative cohort indices and
ID and cohort vectors are of the same length nObs.
h_doses_unique_per_cohort(): helper function which verifies whether
the dose values are unique in each and every different cohort.
h_combo_doses_unique_per_cohort(): helper function which verifies whether the
two-drug dose combination is unique in each cohort.
v_data(): validates that the Data object contains
valid elements with respect to their types, dependency and length.
v_data_dual(): validates that the DataDual object
contains valid biomarker vector with respect to its type and the length.
v_data_parts(): validates that the DataParts object
contains valid elements with respect to their types, dependency and length.
v_data_mixture(): validates that the DataMixture object
contains valid elements with respect to their types, dependency and length.
v_data_da(): validates that the DataDA object
contains valid elements with respect to their types, dependency and length.
v_data_ordinal(): validates that the DataOrdinal object
contains valid elements with respect to their types, dependency and length.
v_data_grouped(): validates that the DataGrouped object
contains valid group information.
v_data_combo(): validates that the DataCombo object
contains valid two-drug combination data.
v_hierarchical_data(): validates that the HierarchicalData object contains valid arms.