v_general_simulations: Internal Helper Functions for Validation of...

View source: R/Simulations-validity.R

v_general_simulationsR Documentation

Internal Helper Functions for Validation of GeneralSimulations Objects

Description

[Stable]

These functions are only used internally to validate the format of an input GeneralSimulations or inherited classes and therefore not exported.

Usage

v_general_simulations(object)

v_simulations(object)

v_hierarchical_simulations(object)

v_combo_simulations(object)

v_dual_simulations(object)

v_da_simulations(object)

Arguments

object

(GeneralSimulations)
object to validate.

Value

A character vector with the validation failure messages, or TRUE in case validation passes.

Functions

  • v_general_simulations(): validates that the GeneralSimulations object contains valid data object and valid dose simulations.

  • v_simulations(): validates that the Simulations object contains valid object fit, stop_reasons, stop_report, and additional_stats compared to the general class GeneralSimulations.

  • v_hierarchical_simulations(): validates that the HierarchicalSimulations object contains valid hierarchical data, posterior samples, fits, and stopping outputs.

  • v_combo_simulations(): validates that the ComboSimulations object contains valid combo data, recommended dose combinations, model fit, and stopping outputs.

  • v_dual_simulations(): validates that the DualSimulations object and capture the dose-biomarker fits, and the sigma2W and rho estimates.

  • v_da_simulations(): validates that the DASimulations object contains valid trial_duration the vector of trial duration values for all simulations.


crmPack documentation built on July 5, 2026, 9:06 a.m.