v_recruitment: Internal Helper Functions for Validation of 'Recruitment'...

v_recruitmentR Documentation

Internal Helper Functions for Validation of Recruitment Objects

Description

[Experimental]

These functions are only used internally to validate the format of an input Recruitment or inherited classes and therefore not exported.

Usage

v_recruitment_ratio(object)

Arguments

object

(Recruitment) object to validate.

Value

A character vector with the validation failure messages, or TRUE in case validation passes.

Functions

  • v_recruitment_ratio(): validates that the RecruitmentRatio object contains valid ratio slot.


crmPack documentation built on July 5, 2026, 9:06 a.m.