Samples ObjectsThese functions are only used internally to validate the format
of an input Samples or inherited classes and therefore not exported.
v_samples(object)v_hierarchical_samples(object)
A character vector with the validation failure messages, or TRUE
in case validation passes.
(Samples)
object to validate.
v_samples(): validates that the Samples object contains
valid data slot.
v_hierarchical_samples(): validates that the HierarchicalSamples
object contains valid per-arm sample mappings.