| ArmMinDoseCondition-class | R Documentation |
ArmMinDoseConditionArmMinDoseCondition opens an arm when the named arm has enrolled at
least one patient at the specified minimum dose or higher.
ArmMinDoseCondition(arm_name, min_dose)
.DefaultArmMinDoseCondition()
arm_name |
( |
min_dose |
( |
arm_name(string)
the name of the arm whose data are checked.
min_dose(numeric)
the minimum dose that must have been reached.
For combination arms, this can be a vector of minimum doses for each agent.
Typically, end users will not use the .DefaultArmMinDoseCondition()
function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.