ArmMinDoseConditionArmMinDoseCondition opens an arm when the named arm has enrolled at
least one patient at the specified minimum dose or higher.
ArmMinDoseCondition(arm_name, min_dose).DefaultArmMinDoseCondition()
(string)
see slot definition.
(numeric)
see slot definition.
arm_name(string)
the name of the arm whose data are checked.
min_dose(numeric)
the minimum dose that must have been reached.
For combination arms, this can be a vector of minimum doses for each agent.