| DataCombo-class | R Documentation |
DataComboDataCombo is a class for two-drug combination toxicity data.
It inherits from GeneralData and stores patient-level dose combinations.
DataCombo(
x = matrix(numeric(), ncol = 2L),
y = integer(),
ID = integer(),
cohort = integer(),
doseGrid = list(drug1 = numeric(), drug2 = numeric()),
drugNames = names(doseGrid),
backfilled = rep(FALSE, nrow(x)),
response = rep(NA_integer_, nrow(x)),
...
)
.DefaultDataCombo()
x |
( |
y |
( |
ID |
( |
cohort |
( |
doseGrid |
( |
drugNames |
( |
backfilled |
( |
response |
( |
... |
not used. |
x(matrix)
numeric matrix with 2 columns giving the doses of the two drugs.
y(integer)
the vector of toxicity events (0 or 1 integers).
doseGrid(list)
named list of length 2 with the possible doses for each drug.
nGrid(integer)
number of grid points for each drug.
xLevel(matrix)
integer matrix with 2 columns giving the dose levels of x with respect to
doseGrid.
drugNames(character)
names of the two drugs.
backfilled(logical)
whether this patient was in a backfill cohort.
response(integer)
whether this patient had a positive efficacy response (0/1/NA).
ID and cohort can be missing. Then a message will be issued
and the variables will be filled with default IDs and best guess cohort
indices.
Typically, end users will not use the .DefaultDataCombo() function.
## Example for DataCombo ----
DataCombo(
x = cbind(
drug1 = c(10, 10, 10, 20, 20, 20),
drug2 = c(20, 20, 20, 20, 20, 20)
),
y = c(0L, 0L, 1L, 0L, 0L, 0L),
ID = 1L:6L,
cohort = c(1L, 1L, 1L, 2L, 2L, 2L),
doseGrid = list(
drug1 = c(10, 20, 30),
drug2 = c(20, 40)
)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.