Learn R Programming

crmPack (version 2.2.1)

HierarchicalData-class: HierarchicalData

Description

[Experimental]

HierarchicalData is a class for hierarchical designs, storing the data for all arms together.

Usage

HierarchicalData(...)

.DefaultHierarchicalData()

Arguments

...

named Data objects, one for each arm in the trial. The argument names are used as the arm names.

Slots

arms

(list)
a named list of Data objects, one for each arm in the trial. The names of the list are the arm names.

Examples

Run this code
dat_hierarchical <- HierarchicalData(
  mono = .DefaultData(),
  combo = .DefaultDataCombo()
)

Run the code above in your browser using DataLab