powered by
HierarchicalData
HierarchicalData is a class for hierarchical designs, storing the data for all arms together.
HierarchicalData(...).DefaultHierarchicalData()
.DefaultHierarchicalData()
named Data objects, one for each arm in the trial. The argument names are used as the arm names.
Data
arms
(list) a named list of Data objects, one for each arm in the trial. The names of the list are the arm names.
list
dat_hierarchical <- HierarchicalData( mono = .DefaultData(), combo = .DefaultDataCombo() )
Run the code above in your browser using DataLab