| IncrementsComboCartesian-class | R Documentation |
IncrementsComboCartesianIncrementsComboCartesian is the class for increments control in
combination trials where separate increment rules are defined for each drug
and applied independently.
IncrementsComboCartesian(drug1, drug2)
.DefaultIncrementsComboCartesian()
drug1 |
( |
drug2 |
( |
Under this rule, the maximum admissible dose for each drug is first
computed from the corresponding one-dimensional increment rule. The
resulting two-dimensional admissible region is then represented in a
matrix form compatible with combination maxDose methods.
drug1(Increments)
increment rule for the first drug.
drug2(Increments)
increment rule for the second drug.
Typically, end users will not use the .DefaultIncrementsComboCartesian() function.
# Create independent increment rules for each drug in a two-drug combination
# trial.
drug1_rule <- IncrementsRelative(intervals = c(0, 20), increments = c(1, 0.33))
drug2_rule <- IncrementsRelative(intervals = c(0, 20), increments = c(1, 0.33))
# Combine the one-dimensional rules into a Cartesian combination rule.
my_increments <- IncrementsComboCartesian(
drug1 = drug1_rule,
drug2 = drug2_rule
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.