| OpeningMinDose-class | R Documentation |
OpeningMinDoseOpeningMinDose opens a backfill cohort when the
cohort's dose is above or equal to the minimum dose specified.
Note that the next recommended dose is not taken into account.
OpeningMinDose(min_dose = 0)
.DefaultOpeningMinDose()
min_dose |
( |
min_dose(numeric)
the minimum dose at which backfill
cohorts can be opened. For combination trials, this can be
a vector of minimum doses for each agent.
Typically, end users will not use the .DefaultOpeningMinDose() function.
Opening and the other subclasses listed in there.
# Opening backfill cohort when dose is at least 50
my_opening <- OpeningMinDose(min_dose = 50)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.