| TITELogisticLogNormalSub-class | R Documentation |
TITELogisticLogNormalSubTITELogisticLogNormalSub is the class for TITE-CRM based on a logistic
regression model with subtractive dose standardization and a bivariate
normal prior on the intercept and log slope parameters.
This class inherits from LogisticLogNormalSub.
TITELogisticLogNormalSub(weight_method = "linear", ...)
.DefaultTITELogisticLogNormalSub()
weight_method |
( |
... |
Arguments passed on to
|
Basically, the adaptive function allocates more weight to each record than the linear function when DLTs are observed early and less weight when DLTs are observed late. When DLT times are evenly distributed both weights are similar. In addition, with more DLTs, the adaptive weights become more extreme and different from the linear weights.
weight_method(string)
the weight function method: either linear
or adaptive; see \insertCiteLiuYinYuan2013;textualcrmPack.
Typically, end users will not use the .DefaultTITELogisticLogNormalSub() function.
TITELogisticLogNormal, DALogisticLogNormal.
my_model <- TITELogisticLogNormalSub(
mean = c(-0.85, 1),
cov = matrix(c(1, -0.5, -0.5, 1), nrow = 2),
ref_dose = 50,
weight_method = "linear"
)
my_model1 <- TITELogisticLogNormalSub(
mean = c(-0.85, 1),
cov = matrix(c(1, -0.5, -0.5, 1), nrow = 2),
ref_dose = 50,
weight_method = "adaptive"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.