View source: R/helpers_rules.R
| h_dose_combo_below_limit | R Documentation |
Helper function that checks if the doses in a dose matrix are below the dose limit.
h_dose_combo_below_limit(dose_matrix, dose_limit)
dose_matrix |
( |
dose_limit |
( |
A logical vector indicating whether the doses in each row of the dose matrix are below the corresponding dose limits.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.