View source: R/helpers_design.R
| h_enroll_backfill_patients | R Documentation |
This function executes backfill enrollment according to the priority rule, updating the data object, backfill cohort queue, and patient counter.
h_enroll_backfill_patients(
backfill_cohorts,
data,
backfill,
cohort_size,
backfill_patients,
current_args,
truth,
truthResponse
)
backfill_cohorts |
( |
data |
( |
backfill |
( |
cohort_size |
( |
backfill_patients |
( |
current_args |
( |
truth |
( |
truthResponse |
( |
List with updated data, backfill_cohorts, and
backfill_patients.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.