View source: R/Simulations-methods.R
| h_eval_combo_truth | R Documentation |
Evaluates the true toxicity probability at a given dose combination using the
provided truth function. The truth function can be flexible in how it
accepts the dose combination as input, and this helper tries different ways to
call it in order to extract the toxicity probability.
h_eval_combo_truth(truth, dose_pair, ...)
truth |
( |
dose_pair |
( |
... |
additional arguments passed to |
A numeric value representing the true toxicity probability at the given dose
combination, or NA_real_ if it cannot be evaluated.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.