h_find_interval: Find Interval Numbers or Indices and Return Custom Number For 0.
Description
A simple wrapper of base::findInterval() function that invokes
base::findInterval(), takes its output and replaces all the
elements with \(0\) value to a custom number as specified in replacement
argument.