View source: R/Simulations-methods.R
| h_hierarchical_get_arm_arg | R Documentation |
Returns the arm-specific value from a named list, or returns the original value unchanged when a single shared value was supplied.
h_hierarchical_get_arm_arg(arg, arm_name)
arg |
( |
arm_name |
( |
The selected arm-specific argument, or arg unchanged.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.