View source: R/HierarchicalDesign-methods.R
| h_hierarchical_get_decision_samples | R Documentation |
In a hierarchical design, the samples used for decision rules in each arm may either be the overall samples from the hierarchical model (if borrowing is allowed) or the arm-specific samples (if no borrowing).
h_hierarchical_get_decision_samples(
samples,
arm_name,
arm,
arm_data,
mcmcOptions
)
samples |
the overall samples from the hierarchical model. |
arm_name |
the name of the arm for which we want to get the samples for decision rules. |
arm |
the |
arm_data |
the data for this arm. |
mcmcOptions |
the MCMC options to use if we need to fit an arm-specific model. |
the samples to be used for decision rules for this arm.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.