In a hierarchical design, the samples used for decision rules in each arm may either be the overall samples from the hierarchical model (if borrowing is allowed) or the arm-specific samples (if no borrowing).
h_hierarchical_get_decision_samples(
samples,
arm_name,
arm,
arm_data,
mcmcOptions
)the samples to be used for decision rules for this arm.
the overall samples from the hierarchical model.
the name of the arm for which we want to get the samples for decision rules.
the DesignArm object for this arm.
the data for this arm.
the MCMC options to use if we need to fit an arm-specific model.