Learn R Programming

crmPack (version 2.2.1)

h_hierarchical_parse_ref: Parse a Hierarchical Parameter Reference

Description

[Experimental]

Converts a user-facing parameter reference into metadata that can be used by the JAGS code generators.

Usage

h_hierarchical_parse_ref(model, arm_name, ref)

Value

Named list with entries kind, index, latent, and sample.

Arguments

model

(GeneralModel)
arm-specific model object.

arm_name

(string)
the user-facing arm name.

ref

(string)
parameter reference.