View source: R/HierarchicalModel-class.R
| h_hierarchical_pool_names | R Documentation |
Returns the hierarchical pool membership of each parameter reference, or an empty string if the parameter keeps its arm-specific fixed prior.
h_hierarchical_pool_names(arm_name, refs, pooled_map)
arm_name |
( |
refs |
( |
pooled_map |
( |
Character vector of pool names, using "" for unpooled parameters.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.