Returns the hierarchical pool membership of each parameter reference, or an empty string if the parameter keeps its arm-specific fixed prior.
h_hierarchical_pool_names(arm_name, refs, pooled_map)Character vector of pool names, using "" for unpooled parameters.
(string)
arm name.
(character)
parameter references belonging to that arm.
(list)
output of
h_hierarchical_make_pool_map().