Learn R Programming

crmPack (version 2.2.1)

h_historical_arm_design: Construct a simplified DesignArm with hardcoded rule objects

Description

Construct a simplified DesignArm with hardcoded rule objects

Usage

h_historical_arm_design(data, model)

Value

A Design object with hardcoded rules for historical arms. The rules don't matter because they won't be used, but they are required to construct a Design object.

Arguments

data

(Data or DataCombo)
arm data for historical arms.

model

(GeneralModel or TwoDrugsCombo)
arm model for historical arms.