View source: R/Model-methods.R
| h_prob_two_drugs_combo | R Documentation |
Combines delegated single-agent toxicity probabilities with the combo interaction term. Both the monotherapy probabilities and the interaction covariate follow the corresponding single-agent model definitions.
h_prob_two_drugs_combo(dose, model, samples)
dose |
( |
model |
( |
samples |
( |
Numeric vector for one dose combination, otherwise numeric matrix with one row per posterior sample and one column per dose combination.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.