Combines delegated single-agent toxicity probabilities with the combo interaction term. Both the monotherapy probabilities and the interaction covariate follow the corresponding single-agent model definitions.
h_prob_two_drugs_combo(dose, model, samples)Numeric vector for one dose combination, otherwise numeric matrix with one row per posterior sample and one column per dose combination.
(numeric or matrix)
one or more combo dose combinations.
(TwoDrugsCombo)
combo model.
(Samples)
combo model samples.