View source: R/helpers_design.R
| h_update_backfill_queue | R Documentation |
This function manages the backfill cohort queue by determining which previous cohorts are open or closed for backfill enrollment.
h_update_backfill_queue(backfill_cohorts, data, dose, backfill)
backfill_cohorts |
( |
data |
( |
dose |
( |
backfill |
( |
Updated backfill_cohorts list.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.