ComboSimulationsSummarize two-drug combination simulations with plots.
This plot method can be applied to ComboSimulations objects. Possible
types of plots are:
Summary of simulated dose trajectories for each drug
Average proportions of tested doses for each drug
2D dose-plane evolution with arrows for dose transitions, and labels showing DLTs/patients plus a step index hint
# S4 method for ComboSimulations,missing
plot(x, y, type = c("trajectory", "dosesTried", "trajectory2D"), ...)A single ggplot object if a single panel is produced, otherwise
a gtable object.
(ComboSimulations)
the object we want to plot from.
(missing)
not used.
(character)
the type of plots you want to obtain.
not used.