| plot,ComboSimulations,missing-method | R Documentation |
ComboSimulationsSummarize two-drug combination simulations with plots.
This plot method can be applied to ComboSimulations objects. Possible
types of plots are:
Summary of simulated dose trajectories for each drug
Average proportions of tested doses for each drug
2D dose-plane evolution with arrows for dose transitions, and labels showing DLTs/patients plus a step index hint
## S4 method for signature 'ComboSimulations,missing'
plot(x, y, type = c("trajectory", "dosesTried", "trajectory2D"), ...)
x |
( |
y |
( |
type |
( |
... |
not used. |
A single ggplot object if a single panel is produced, otherwise
a gtable object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.