ComboSimulationsSummarize two-drug combination simulations.
# S4 method for ComboSimulations
summary(object, truth, target = c(0.2, 0.35), ...)An object of class ComboSimulationsSummary.
(ComboSimulations)
the object we want to summarize.
(function)
optional function mapping a dose combination to a toxicity probability.
It can accept one argument (length-2 numeric vector or one-row matrix) or
two numeric arguments (drug1, drug2).
(numeric)
optional target toxicity interval used only when truth is supplied.
additional arguments can be supplied here for truth.