Summarize hierarchical simulations by delegating to the corresponding arm-level simulation summary methods.
# S4 method for HierarchicalSimulations
summary(object, truth, target = c(0.2, 0.35), ...)An object of class HierarchicalSimulationsSummary.
(HierarchicalSimulations)
the object we want to summarize.
(function or named list of function)
true DLT
probability function(s). If a list is supplied, names must match the
hierarchical arms.
(numeric or named list of numeric)
target toxicity
interval(s). If a list is supplied, names must match the hierarchical arms.
additional arguments can be supplied here for truth.